@@ -3,7 +3,7 @@
 
   Copyright (C) 2002-2003 Daniel Molkentin <molkentin@kde.org>
   Copyright (C) 2004-2006 Michael Brade <brade@kde.org>
-  Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
@@ -220,8 +220,8 @@ KNotesPart::KNotesPart(QObject *parent)
     connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemRemoved,
             this, &KNotesPart::slotItemRemoved);
 
-    connect(mNoteRecorder->changeRecorder(), SIGNAL(collectionChanged(Akonadi::Collection,QSet<QByteArray>)),
-            SLOT(slotCollectionChanged(Akonadi::Collection,QSet<QByteArray>)));
+    connect(mNoteRecorder->changeRecorder(), QOverload<const Akonadi::Collection &, const QSet<QByteArray> &>::of(&Akonadi::ChangeRecorder::collectionChanged),
+            this, &KNotesPart::slotCollectionChanged);
 
     mSelectionModel = new QItemSelectionModel(mNoteTreeModel);
     mModelProxy = new KCheckableProxyModel(this);
@@ -241,8 +241,8 @@ KNotesPart::KNotesPart(QObject *parent)
     actionCollection()->addAction(QStringLiteral("focus_to_quickseach"), mQuickSearchAction);
     connect(mQuickSearchAction, &QAction::triggered, mNotesWidget, &KNotesWidget::slotFocusQuickSearch);
 
-    connect(mNotesWidget->notesView(), SIGNAL(itemDoubleClicked(QListWidgetItem*)),
-            this, SLOT(editNote(QListWidgetItem*)));
+    connect(mNotesWidget->notesView(), &QListWidget::itemDoubleClicked,
+            this, QOverload<QListWidgetItem *>::of(&KNotesPart::editNote));
 
     connect(mNotesWidget->notesView(), &QListWidget::itemSelectionChanged,
             this, &KNotesPart::slotOnCurrentChanged);
@@ -635,7 +635,7 @@ void KNotesPart::slotPreferences()
 {
     // create a new preferences dialog...
     KNoteConfigDialog *dialog = new KNoteConfigDialog(i18n("Settings"), widget());
-    connect(dialog, SIGNAL(configCommitted()), this, SLOT(slotConfigUpdated()));
+    connect(dialog, QOverload<>::of(&KCMultiDialog::configCommitted), this, &KNotesPart::slotConfigUpdated);
     dialog->show();
 }
 
